@@ -5,6 +5,8 @@ module Language.Cimple.Pretty
     , render
     , renderSmart
     , ppTranslationUnit
+    , ppNode
+    , ppNodeF
     , showNode
     , showNodePlain
     ) where
@@ -199,10 +201,10 @@ ppMacroBody =
     . plain
 
 ppNode :: Pretty a => Node (Lexeme a) -> Doc AnsiStyle
-ppNode = foldFix go
-  where
-  go :: Pretty a => NodeF (Lexeme a) (Doc AnsiStyle) -> Doc AnsiStyle
-  go = \case
+ppNode = foldFix ppNodeF
+
+ppNodeF :: Pretty a => NodeF (Lexeme a) (Doc AnsiStyle) -> Doc AnsiStyle
+ppNodeF = \case
     StaticAssert cond msg ->
         kwStaticAssert <> parens (cond <> comma <+> dullred (ppLexeme msg)) <> semi
 
@@ -237,7 +239,6 @@ ppNode = foldFix go
     FunctionCall c  a    -> ppFunctionCall c a
     ArrayAccess  e  i    -> e <> pretty '[' <> i <> pretty ']'
     CastExpr     ty e    -> parens ty <> e
-    CompoundExpr    ty e -> parens ty <+> lbrace <> e <> rbrace  -- DEPRECATED
     CompoundLiteral ty e -> parens ty <+> lbrace <> e <> rbrace
     PreprocDefined  n    -> pretty "defined(" <> ppLexeme n <> pretty ')'
     InitialiserList l    -> ppInitialiserList l
@@ -247,9 +248,9 @@ ppNode = foldFix go
     Ellipsis             -> pretty "..."
 
     VarDecl ty name arrs      -> ty <+> ppLexeme name <> hcat arrs
-    DeclSpecArray Nothing     -> pretty "[]"
-    DeclSpecArray (Just dim)  -> brackets dim
-    ArrayDim nullability size -> ppNullability nullability <+> size
+    DeclSpecArray nullability Nothing -> brackets (ppNullability nullability)
+    DeclSpecArray NullabilityUnspecified (Just dim) -> brackets dim
+    DeclSpecArray nullability (Just dim) -> brackets (ppNullability nullability <+> dim)
 
     TyBitwise     ty -> kwBitwise <+> ty
     TyForce       ty -> kwForce <+> ty
